@@ -1,31 +1,30 @@
 // This may look like C code, but it is really -*- C++ -*-
 //
-// Copyright Bob Friesenhahn, 1999, 2000, 2001
+// Copyright Bob Friesenhahn, 1999, 2000, 2001, 2002, 2003
 //
 // Color Implementation
 //
 #if !defined (Magick_Color_header)
 #define Magick_Color_header
 
-#include <string>
-
 #include "Magick++/Include.h"
+#include <string>
 
 namespace Magick
 {
 
-  class Color;
+  class MagickDLLDecl Color;
 
   // Compare two Color objects regardless of LHS/RHS
-  int operator == ( const Magick::Color& left_, const Magick::Color& right_ );
-  int operator != ( const Magick::Color& left_, const Magick::Color& right_ );
-  int operator >  ( const Magick::Color& left_, const Magick::Color& right_ );
-  int operator <  ( const Magick::Color& left_, const Magick::Color& right_ );
-  int operator >= ( const Magick::Color& left_, const Magick::Color& right_ );
-  int operator <= ( const Magick::Color& left_, const Magick::Color& right_ );
+  int MagickDLLDecl operator == ( const Magick::Color& left_, const Magick::Color& right_ );
+  int MagickDLLDecl operator != ( const Magick::Color& left_, const Magick::Color& right_ );
+  int MagickDLLDecl operator >  ( const Magick::Color& left_, const Magick::Color& right_ );
+  int MagickDLLDecl operator <  ( const Magick::Color& left_, const Magick::Color& right_ );
+  int MagickDLLDecl operator >= ( const Magick::Color& left_, const Magick::Color& right_ );
+  int MagickDLLDecl operator <= ( const Magick::Color& left_, const Magick::Color& right_ );
 
   // Base color class stores RGB components scaled to fit Quantum
-  class Color
+  class MagickDLLDecl Color
   {
   public:
     Color ( Quantum red_,
@@ -35,25 +34,25 @@ namespace Magick
 	    Quantum green_,
 	    Quantum blue_,
 	    Quantum alpha_ );
-    Color ( const std::string x11color_ );
+    Color ( const std::string &x11color_ );
     Color ( const char * x11color_ );
     Color ( void );
     virtual        ~Color ( void );
     Color ( const Color & color_ );
 
-    // Red color (range 0 to MaxRGB)
+    // Red color (range 0 to QuantumRange)
     void           redQuantum ( Quantum red_ );
     Quantum        redQuantum ( void ) const;
 
-    // Green color (range 0 to MaxRGB)
+    // Green color (range 0 to QuantumRange)
     void           greenQuantum ( Quantum green_ );
     Quantum        greenQuantum ( void ) const;
 
-    // Blue color (range 0 to MaxRGB)
+    // Blue color (range 0 to QuantumRange)
     void           blueQuantum ( Quantum blue_ );
     Quantum        blueQuantum ( void ) const;
 
-    // Alpha level (range OpaqueOpacity=0 to TransparentOpacity=MaxRGB)
+    // Alpha level (range OpaqueOpacity=0 to TransparentOpacity=QuantumRange)
     void           alphaQuantum ( Quantum alpha_ );
     Quantum        alphaQuantum ( void ) const;
 
@@ -67,33 +66,50 @@ namespace Magick
     bool           isValid ( void ) const;
     
     // Set color via X11 color specification string
-    const Color& operator= ( std::string x11color_ );
+    const Color& operator= ( const std::string &x11color_ );
     const Color& operator= ( const char * x11color_ );
 
     // Assignment operator
     Color& operator= ( const Color& color_ );
-    
+
     // Return X11 color specification string
     /* virtual */ operator std::string() const;
 
+    // Return ImageMagick PixelPacket
+    operator PixelPacket() const;
+
+    // Construct color via ImageMagick PixelPacket
+    Color ( const PixelPacket &color_ );
+
+    // Set color via ImageMagick PixelPacket
+    const Color& operator= ( const PixelPacket &color_ );
+
     //
     // Public methods beyond this point are for Magick++ use only.
     //
 
-    // Construct color via ImageMagick PixelPacket
-    Color ( PixelPacket &color_ );
+    // Obtain pixel intensity as a double
+    double intensity ( void ) const
+      {
+        return (0.299*(_pixel->red)+0.587*(_pixel->green)+0.114*(_pixel->blue));
+      }
 
-    // Set color via ImageMagick PixelPacket
-    const Color& operator= ( PixelPacket &color_ );
+    // Scale a value expressed as a double (0-1) to Quantum range (0-QuantumRange)
+    static Quantum scaleDoubleToQuantum( const double double_ )
+      {
+        return (static_cast<Magick::Quantum>(double_*QuantumRange));
+      }
 
-    // Return ImageMagick PixelPacket
-    operator PixelPacket() const;
+    // Scale a value expressed as a Quantum (0-QuantumRange) to double range (0-1)
+    static double scaleQuantumToDouble( const Quantum quantum_ )
+      {
+        return (static_cast<double>(quantum_)/QuantumRange);
+      }
+    static double scaleQuantumToDouble( const double quantum_ )
+      {
+        return (quantum_/QuantumRange);
+      }
 
-    // Scale a value expressed as a double (0-1) to Quantum range (0-MaxRGB)
-    static Quantum scaleDoubleToQuantum( const double double_ );
-
-    // Scale a value expressed as a Quantum (0-MaxRGB) to double range (0-1)
-    static double scaleQuantumToDouble( const Quantum quantum_ );
 
   protected:
 
@@ -106,12 +122,12 @@ namespace Magick
     //   Red      = red;
     //   Green    = green;
     //   Blue     = blue;
-    //   Alpha    = index;
+    //   Alpha    = opacity;
     // CYMKPixel:
     //   Cyan     = red
     //   Yellow   = green
     //   Magenta  = blue
-    //   Black(K) = index
+    //   Black(K) = opacity
     enum PixelType
     {
       RGBPixel,
@@ -128,10 +144,10 @@ namespace Magick
     void pixel ( PixelPacket* rep_, PixelType pixelType_ );
 
     // PixelPacket represents a color pixel:
-    //  red     = red   (range 0 to MaxRGB)
-    //  green   = green (range 0 to MaxRGB)
-    //  blue    = blue  (range 0 to MaxRGB)
-    //  opacity = alpha (range OpaqueOpacity=0 to TransparentOpacity=MaxRGB)
+    //  red     = red   (range 0 to QuantumRange)
+    //  green   = green (range 0 to QuantumRange)
+    //  blue    = blue  (range 0 to QuantumRange)
+    //  opacity = alpha (range OpaqueOpacity=0 to TransparentOpacity=QuantumRange)
     //  index   = PseudoColor colormap index
     PixelPacket*     _pixel;
 
@@ -151,7 +167,7 @@ namespace Magick
   //
   // HSL Colorspace colors
   //
-  class ColorHSL : public Color
+  class MagickDLLDecl ColorHSL : public Color
   {
   public:
     ColorHSL ( double hue_, double saturation_, double luminosity_ );
@@ -181,7 +197,7 @@ namespace Magick
   //
   // Grayscale is simply RGB with equal parts of red, green, and blue
   // All double arguments have a valid range of 0.0 - 1.0.
-  class ColorGray : public Color
+  class MagickDLLDecl ColorGray : public Color
   {
   public:
     ColorGray ( double shade_ );
@@ -205,7 +221,7 @@ namespace Magick
   //
   // Color arguments are constrained to 'false' (black pixel) and 'true'
   // (white pixel)
-  class ColorMono : public Color
+  class MagickDLLDecl ColorMono : public Color
   {
   public:
     ColorMono ( bool mono_ );
@@ -228,7 +244,7 @@ namespace Magick
   // RGB color
   //
   // All color arguments have a valid range of 0.0 - 1.0.
-  class ColorRGB : public Color
+  class MagickDLLDecl ColorRGB : public Color
   {
   public:
     ColorRGB ( double red_, double green_, double blue_ );
@@ -260,7 +276,7 @@ namespace Magick
   //        Y:  0.0 through 1.0
   //        U: -0.5 through 0.5
   //        V: -0.5 through 0.5
-  class ColorYUV : public Color
+  class MagickDLLDecl ColorYUV : public Color
   {
   public:
     ColorYUV ( double y_, double u_, double v_ );
@@ -294,18 +310,6 @@ namespace Magick
 // Color
 //
 
-// Scale a value expressed as a double (0-1) to Quantum range (0-MaxRGB)
-inline Magick::Quantum Magick::Color::scaleDoubleToQuantum( const double double_ )
-{
-  return (static_cast<Magick::Quantum>(double_*MaxRGB));
-}
-
-// Scale a value expressed as a Quantum (0-MaxRGB) to double range (0-1)
-inline double Magick::Color::scaleQuantumToDouble( const Magick::Quantum quantum_ )
-{
-  return (static_cast<double>(quantum_/MaxRGB));
-}
-
 // Common initializer for PixelPacket representation
 // Initialized to state that ImageMagick considers to be
 // an invalid color.
@@ -317,7 +321,7 @@ inline void Magick::Color::initPixel()
   _pixel->opacity = TransparentOpacity;
 }
 
-inline void Magick::Color::redQuantum ( Quantum red_ )
+inline void Magick::Color::redQuantum ( Magick::Quantum red_ )
 {
   _pixel->red = red_;
 }
@@ -327,7 +331,7 @@ inline Magick::Quantum Magick::Color::redQuantum ( void ) const
   return _pixel->red;
 }
 
-inline void Magick::Color::greenQuantum ( Quantum green_ )
+inline void Magick::Color::greenQuantum ( Magick::Quantum green_ )
 {
   _pixel->green = green_;
 }
@@ -337,7 +341,7 @@ inline Magick::Quantum  Magick::Color::greenQuantum ( void ) const
   return _pixel->green;
 }
 
-inline void  Magick::Color::blueQuantum ( Quantum blue_ )
+inline void  Magick::Color::blueQuantum ( Magick::Quantum blue_ )
 {
   _pixel->blue = blue_;
 }
@@ -347,7 +351,7 @@ inline Magick::Quantum Magick::Color::blueQuantum ( void ) const
   return _pixel->blue;
 }
 
-inline void  Magick::Color::alphaQuantum ( Quantum alpha_ )
+inline void  Magick::Color::alphaQuantum ( Magick::Quantum alpha_ )
 {
   _pixel->opacity = alpha_;
 }
@@ -357,83 +361,12 @@ inline Magick::Quantum Magick::Color::alphaQuantum ( void ) const
   return _pixel->opacity;
 }
 
-inline Magick::Color::Color ( Quantum red_,
-			      Quantum green_,
-			      Quantum blue_ )
-  : _pixel(new PixelPacket),
-    _pixelOwn(true),
-    _pixelType(RGBPixel)
+// Return ImageMagick PixelPacket struct based on color.
+inline Magick::Color::operator MagickLib::PixelPacket () const
 {
-  redQuantum   ( red_   );
-  greenQuantum ( green_ );
-  blueQuantum  ( blue_  );
-  alphaQuantum ( OpaqueOpacity );
+  return *_pixel;
 }
 
-inline Magick::Color::Color ( Quantum red_,
-			      Quantum green_,
-			      Quantum blue_,
-			      Quantum alpha_ )
-  : _pixel(new PixelPacket),
-    _pixelOwn(true),
-    _pixelType(RGBAPixel)
-{
-  redQuantum   ( red_   );
-  greenQuantum ( green_ );
-  blueQuantum  ( blue_  );
-  alphaQuantum ( alpha_ );
-}
-
-// Construct from color expressed as C++ string
-inline Magick::Color::Color ( const std::string x11color_ )
-  : _pixel(new PixelPacket),
-    _pixelOwn(true),
-    _pixelType(RGBPixel)
-{
-  initPixel();
-
-  // Use operator = implementation
-  *this = x11color_;
-}
-
-// Construct from color expressed as C string
-inline Magick::Color::Color ( const char * x11color_ )
-  : _pixel(new PixelPacket),
-    _pixelOwn(true),
-    _pixelType(RGBPixel)
-{
-  initPixel();
-
-  // Use operator = implementation
-  *this = x11color_;
-}
-
-// Default constructor
-inline Magick::Color::Color ( void )
-  : _pixel(new PixelPacket),
-    _pixelOwn(true),
-    _pixelType(RGBPixel)
-{
-  initPixel();
-}
-
-// Protected constructor to construct with PixelPacket*
-// Used to point Color at a pixel.
-inline Magick::Color::Color ( PixelPacket* rep_, PixelType pixelType_  )
-  : _pixel(rep_),
-    _pixelOwn(false),
-    _pixelType(pixelType_)
-{
-}
-
-// Destructor
-inline Magick::Color::~Color( void )
-{
-  if ( _pixelOwn )
-    delete _pixel;
-}
-
-
 // Scaled version of alpha for use in sub-classes
 inline void  Magick::Color::alpha ( double alpha_ )
 {
@@ -444,45 +377,11 @@ inline double Magick::Color::alpha ( void ) const
   return scaleQuantumToDouble( alphaQuantum() );
 }
 
-// Does object contain valid color?
-inline bool Magick::Color::isValid ( void ) const
-{
-  return( _pixel->opacity != TransparentOpacity ||
-          _pixel->red != 0 ||
-          _pixel->green != 0 ||
-          _pixel->blue != 0 );
-}
-inline void Magick::Color::isValid ( bool valid_ )
-{
-  if ( (valid_ && isValid()) || (!valid_ && !isValid()) )
-    return;
-
-  if ( !_pixelOwn )
-    {
-      _pixel = new PixelPacket;
-      _pixelOwn = true;
-    }
-
-  initPixel();
-}
-
-
-    // Set pixel
-    // Used to point Color at a pixel in an image
-inline void Magick::Color::pixel ( PixelPacket* rep_, PixelType pixelType_ )
-{
-  if ( _pixelOwn )
-    delete _pixel;
-  _pixel = rep_;
-  _pixelOwn = false;
-  _pixelType = pixelType_;
-}
-
 //
 // ColorHSL
 //
-inline Magick::ColorHSL::ColorHSL ( PixelPacket* rep_,
-                                    PixelType pixelType_ )
+inline Magick::ColorHSL::ColorHSL ( Magick::PixelPacket* rep_,
+                                    Magick::Color::PixelType pixelType_ )
 : Color( rep_, pixelType_ )
 {
 }
@@ -490,8 +389,8 @@ inline Magick::ColorHSL::ColorHSL ( PixelPacket* rep_,
 //
 // ColorGray
 //
-inline Magick::ColorGray::ColorGray ( PixelPacket* rep_,
-                                      PixelType pixelType_ )
+inline Magick::ColorGray::ColorGray ( Magick::PixelPacket* rep_,
+                                      Magick::Color::PixelType pixelType_ )
 : Color( rep_, pixelType_ )
 {
 }
@@ -499,8 +398,8 @@ inline Magick::ColorGray::ColorGray ( PixelPacket* rep_,
 //
 // ColorMono
 //
-inline Magick::ColorMono::ColorMono ( PixelPacket* rep_,
-                                      PixelType pixelType_ )
+inline Magick::ColorMono::ColorMono ( Magick::PixelPacket* rep_,
+                                      Magick::Color::PixelType pixelType_ )
   : Color( rep_, pixelType_ )
 {
 }
@@ -508,8 +407,8 @@ inline Magick::ColorMono::ColorMono ( PixelPacket* rep_,
 //
 // ColorRGB
 //
-inline Magick::ColorRGB::ColorRGB ( PixelPacket* rep_,
-                                    PixelType pixelType_ )
+inline Magick::ColorRGB::ColorRGB ( Magick::PixelPacket* rep_,
+                                    Magick::Color::PixelType pixelType_ )
   : Color( rep_, pixelType_ )
 {
 }
@@ -548,8 +447,8 @@ inline double Magick::ColorRGB::blue ( void ) const
 // ColorYUV
 //
 
-inline Magick::ColorYUV::ColorYUV ( PixelPacket* rep_,
-                                    PixelType pixelType_ )
+inline Magick::ColorYUV::ColorYUV ( Magick::PixelPacket* rep_,
+                                    Magick::Color::PixelType pixelType_ )
   : Color( rep_, pixelType_ )
 {
 }
