@@ -2,7 +2,7 @@
 //
 // Copyright Bob Friesenhahn, 1999, 2000, 2001, 2002
 //
-// Inclusion of GraphicsMagick headers (with namespace magic)
+// Inclusion of ImageMagick headers (with namespace magic)
 
 #ifndef Magick_Include_header
 #define Magick_Include_header
@@ -10,9 +10,9 @@
 #if !defined(_MAGICK_CONFIG_H)
 # define _MAGICK_CONFIG_H
 # if !defined(vms) && !defined(macintosh)
-#  include "magick/magick_config.h"
+#  include "magick/magick-config.h"
 # else
-#  include "magick_config.h"
+#  include "magick-config.h"
 # endif
 # undef inline // Remove possible definition from config.h
 # undef class
@@ -20,18 +20,13 @@
 
 // Needed for stdio FILE
 #include <stdio.h>
-
-// Needed for time_t
+#include <stdarg.h>
 #include <time.h>
 
 #if defined(HAVE_SYS_TYPES_H)
 # include <sys/types.h>
 #endif
 
-#if defined(HAVE_INTTYPES_H)
-#  include <inttypes.h>
-#endif
-
 #if defined(macintosh)
 #  include <stat.mac.h>  /* Needed for off_t */
 #endif
@@ -41,15 +36,15 @@
 #endif // defined(__BORLANDC__)
 
 //
-// Include GraphicsMagick headers into namespace "MagickLib". If
-// MAGICK_IMPLEMENTATION is defined, include GraphicsMagick development
+// Include ImageMagick headers into namespace "MagickLib". If
+// MAGICKCORE_IMPLEMENTATION is defined, include ImageMagick development
 // headers.  This scheme minimizes the possibility of conflict with
 // user code.
 //
 namespace MagickLib
 {
-#include <magick/api.h>
-#include <wand/magick_wand.h>
+#include <magick/MagickCore.h>
+#include <wand/magick-wand.h>
 #undef inline // Remove possible definition from config.h
 
 #undef class
@@ -59,14 +54,17 @@ namespace MagickLib
 // Provide appropriate DLL imports/exports for Visual C++,
 // Borland C++Builder and MinGW builds
 //
-#if defined(WIN32) && !defined(__CYGWIN__)
-# define MagickWIN32
+#if defined(WIN32) && !defined(__CYGWIN__) && !defined(__MINGW32__)
+# define MagickCplusPlusDLLSupported
 #endif
-#if defined(MagickWIN32)
+#if defined(MagickCplusPlusDLLSupported)
 #  if defined(_MT) && defined(_DLL) && !defined(_LIB)
 #    define MagickDLLBuild
-#    pragma warning( disable: 4273 )      /* Disable the stupid dll linkage warnings */
-#    if !defined(MAGICK_IMPLEMENTATION)
+#    if defined(_VISUALC_)
+#      pragma warning( disable: 4273 )  /* Disable the stupid dll linkage warnings */
+#      pragma warning( disable: 4251 )
+#    endif
+#    if !defined(MAGICKCORE_IMPLEMENTATION)
 #      define MagickDLLDecl __declspec(dllimport)
 #      define MagickDLLDeclExtern extern __declspec(dllimport)
 #      if defined(_VISUALC_)
@@ -99,7 +97,7 @@ namespace MagickLib
 
 
 //
-// Import GraphicsMagick symbols and types which are used as part of the
+// Import ImageMagick symbols and types which are used as part of the
 // Magick++ API definition into namespace "Magick".
 //
 namespace Magick
@@ -107,6 +105,11 @@ namespace Magick
   // The datatype for an RGB component
   using MagickLib::Quantum;
 
+  // Boolean types
+  using MagickLib::MagickBooleanType;
+  using MagickLib::MagickFalse;
+  using MagickLib::MagickTrue;
+
   // Image class types
   using MagickLib::ClassType;
   using MagickLib::UndefinedClass;
@@ -127,22 +130,25 @@ namespace Magick
   using MagickLib::MatteChannel;
   
   // Color-space types
+  using MagickLib::CMYKColorspace;
   using MagickLib::ColorspaceType;
-  using MagickLib::UndefinedColorspace;
-  using MagickLib::RGBColorspace;
   using MagickLib::GRAYColorspace;
-  using MagickLib::TransparentColorspace;
+  using MagickLib::HSLColorspace;
+  using MagickLib::HWBColorspace;
+  using MagickLib::LABColorspace;
   using MagickLib::OHTAColorspace;
+  using MagickLib::Rec601LumaColorspace;
+  using MagickLib::Rec709LumaColorspace;
+  using MagickLib::RGBColorspace;
+  using MagickLib::sRGBColorspace;
+  using MagickLib::TransparentColorspace;
+  using MagickLib::UndefinedColorspace;
   using MagickLib::XYZColorspace;
   using MagickLib::YCbCrColorspace;
   using MagickLib::YCCColorspace;
   using MagickLib::YIQColorspace;
   using MagickLib::YPbPrColorspace;
   using MagickLib::YUVColorspace;
-  using MagickLib::CMYKColorspace;
-  using MagickLib::sRGBColorspace;
-  using MagickLib::HSLColorspace;
-  using MagickLib::HWBColorspace;
   
   // Composition operations
   using MagickLib::AddCompositeOp;
@@ -306,6 +312,18 @@ namespace Magick
   using MagickLib::ImpulseNoise;
   using MagickLib::LaplacianNoise;
   using MagickLib::PoissonNoise;
+
+  // Orientation types
+  using MagickLib::OrientationType;
+  using MagickLib::UndefinedOrientation;
+  using MagickLib::TopLeftOrientation;
+  using MagickLib::TopRightOrientation;
+  using MagickLib::BottomRightOrientation;
+  using MagickLib::BottomLeftOrientation;
+  using MagickLib::LeftTopOrientation;
+  using MagickLib::RightTopOrientation;
+  using MagickLib::RightBottomOrientation;
+  using MagickLib::LeftBottomOrientation;
   
   // Paint methods
   using MagickLib::PaintMethod;
@@ -421,9 +439,9 @@ namespace Magick
   using MagickLib::OverlineDecoration;
   using MagickLib::LineThroughDecoration;
 
-#if defined(MAGICK_IMPLEMENTATION)
+#if defined(MAGICKCORE_IMPLEMENTATION)
   //
-  // GraphicsMagick symbols used in implementation code
+  // ImageMagick symbols used in implementation code
   //
   using MagickLib::AcquireCacheView;
   using MagickLib::AcquireImagePixels;
@@ -469,6 +487,7 @@ namespace Magick
   using MagickLib::ConstituteImage;
   using MagickLib::ContrastImage;
   using MagickLib::ConvolveImage;
+  using MagickLib::CopyMagickString;
   using MagickLib::CorruptImageError;
   using MagickLib::CorruptImageFatalError;
   using MagickLib::CorruptImageWarning;
@@ -485,6 +504,7 @@ namespace Magick
   using MagickLib::DestroyImageInfo;
   using MagickLib::DestroyImageList;
   using MagickLib::DestroyMagick;
+  using MagickLib::DestroyMagickWand;
   using MagickLib::DestroyPixelWand;
   using MagickLib::DestroyQuantizeInfo;
   using MagickLib::DestroyStringInfo;
@@ -547,8 +567,8 @@ namespace Magick
   using MagickLib::DrawSetClipPath;
   using MagickLib::DrawSetClipRule;
   using MagickLib::DrawSetClipUnits;
+  using MagickLib::DrawSetFillAlpha;
   using MagickLib::DrawSetFillColor;
-  using MagickLib::DrawSetFillOpacity;
   using MagickLib::DrawSetFillPatternURL;
   using MagickLib::DrawSetFillRule;
   using MagickLib::DrawSetFont;
@@ -558,6 +578,7 @@ namespace Magick
   using MagickLib::DrawSetFontStyle;
   using MagickLib::DrawSetFontWeight;
   using MagickLib::DrawSetGravity;
+  using MagickLib::DrawSetStrokeAlpha;
   using MagickLib::DrawSetStrokeAntialias;
   using MagickLib::DrawSetStrokeColor;
   using MagickLib::DrawSetStrokeDashArray;
@@ -565,7 +586,6 @@ namespace Magick
   using MagickLib::DrawSetStrokeLineCap;
   using MagickLib::DrawSetStrokeLineJoin;
   using MagickLib::DrawSetStrokeMiterLimit;
-  using MagickLib::DrawSetStrokeOpacity;
   using MagickLib::DrawSetStrokePatternURL;
   using MagickLib::DrawSetStrokeWidth;
   using MagickLib::DrawSetTextAntialias;
@@ -580,12 +600,13 @@ namespace Magick
   using MagickLib::EdgeImage;
   using MagickLib::EmbossImage;
   using MagickLib::EnhanceImage;
-  using MagickLib::ExecuteModuleProcess;
   using MagickLib::EqualizeImage;
   using MagickLib::EvaluateImage;
   using MagickLib::EvaluateImageChannel;
   using MagickLib::ExceptionInfo;
   using MagickLib::ExceptionType;
+  using MagickLib::ExecuteModuleProcess;
+  using MagickLib::ExportQuantumPixels;
   using MagickLib::FileOpenError;
   using MagickLib::FileOpenFatalError;
   using MagickLib::FileOpenWarning;
@@ -602,6 +623,7 @@ namespace Magick
   using MagickLib::GetCacheViewIndexes;
   using MagickLib::GetImageChannelExtrema;
   using MagickLib::GetImageChannelMean;
+  using MagickLib::GetImageClipMask;
   using MagickLib::GetColorTuple;
   using MagickLib::GetDrawInfo;
   using MagickLib::GetExceptionInfo;
@@ -639,15 +661,20 @@ namespace Magick
   using MagickLib::ImageToBlob;
   using MagickLib::ImageWarning;
   using MagickLib::ImplodeImage;
+  using MagickLib::ImportQuantumPixels;
   using MagickLib::IsEventLogging;
   using MagickLib::IsGeometry;
   using MagickLib::IsImagesEqual;
   using MagickLib::IsSubimage;
   using MagickLib::LessValue;
+  using MagickLib::LevelImage;
+  using MagickLib::LevelImageChannel;
   using MagickLib::LocaleCompare;
   using MagickLib::LogMagickEvent;
   using MagickLib::MagickInfo;
+  using MagickLib::MagickPixelPacket;
   using MagickLib::MagickToMime;
+  using MagickLib::MagickWand;
   using MagickLib::MagnifyImage;
   using MagickLib::MapImage;
   using MagickLib::MatteFloodfillImage;
@@ -666,6 +693,7 @@ namespace Magick
   using MagickLib::MontageInfo;
   using MagickLib::NegateImage;
   using MagickLib::NewPixelWand;
+  using MagickLib::NewMagickWandFromImage;
   using MagickLib::NoValue;
   using MagickLib::NoiseType;
   using MagickLib::NormalizeImage;
@@ -681,10 +709,8 @@ namespace Magick
   using MagickLib::PixelSetQuantumColor;
 	using MagickLib::PixelWand;
   using MagickLib::PointInfo;
-  using MagickLib::PopImagePixels;
   using MagickLib::ProfileImage;
   using MagickLib::ProfileInfo;
-  using MagickLib::PushImagePixels;
   using MagickLib::QuantizeImage;
   using MagickLib::QuantizeInfo;
   using MagickLib::QueryColorDatabase;
@@ -773,7 +799,7 @@ namespace Magick
   using MagickLib::YValue;
   using MagickLib::ZoomImage;
 
-#endif // MAGICK_IMPLEMENTATION
+#endif // MAGICKCORE_IMPLEMENTATION
 
 }
 
